@@ -38,6 +38,9 @@ else:
     # python2.7
     from urlparse import urlparse, parse_qsl, urlunparse
 
+import urllib3.contrib.pyopenssl
+urllib3.contrib.pyopenssl.inject_into_urllib3()
+
 logger = logging.getLogger(__name__)
 
 __all__=['EdgeGridAuth']
